(function($, drupalSettings){

  /**
   * CodeMirror behavior
   * @type {Object}
   */

  Drupal.behaviors.codemirror_field = {

    attach: function (context, settings) {

      var $textareas = $('.field--type-codemirror textarea').not('.codemirror-processed'),
        controller = this;

      $.each ($textareas, function (i, textarea) {
        //This is handy if an ajax request reattaches the behaviors, we won't attach codemirror again.
        if ($(textarea).hasClass('codemirror-processed')) {
          return true;
        }

        //Get the instance id from the classes.
        instance = $.grep($(this).closest('.codemirror-instance').get(0).className.split(" "), function (v, i) {
          return v.indexOf('codemirror-instance-') === 0;
        }).join();

        if (instance.length == 0) {
          return true;
        }

        if (typeof settings.codemirror[instance].config != 'undefined') {

          //Fix numeric values in the settings object.
          $.each(settings.codemirror[instance].config, function(key, value) {
            if(!isNaN(value)) {
              settings.codemirror[instance].config[key] = parseInt(value);
            }
          });

          //Add gutter for linter.
          if (typeof settings.codemirror[instance].config['lint'] != 'undefined'
            && settings.codemirror[instance].config['lint'] == 1) {
            settings.codemirror[instance].config['lint'] = true;
            settings.codemirror[instance].config['gutters'] = ["CodeMirror-lint-markers"];
          }

          //Configure match tags.
          if (typeof settings.codemirror[instance].config['matchTags'] != 'undefined'
            && settings.codemirror[instance].config['matchTags'] == 1) {
            settings.codemirror[instance].config['matchTags'] = {
              bothTags: true
            };
          }

          //Attach CodeMirror with the instance settings.
          CodeMirror.fromTextArea(textarea, settings.codemirror[instance].config);
        }

        $('.CodeMirror').next('.grippie').remove();
        controller.loadThemes();

        //Textarea processed.
        $(textarea).addClass('codemirror-processed');

      });
    },

    /**
     * Loads the theme CSS for the codemirror instances.
     */
    loadThemes: function() {
      var themes_path = drupalSettings.codemirror.themes_path;


      $.each(drupalSettings.codemirror, function(i, instanceSettings) {

        if (i.indexOf('codemirror-instance') != 0) {
          return true;
        }

        if (instanceSettings.config.theme == 'default') {
          return true;
        }

        if ($('link[data-cm-theme="' + instanceSettings.config.theme +'"]').length != 0) {
          return true;
        }

        theme_css = themes_path + '/' + instanceSettings.config.theme + '.css';

        $css = $('<link />', {
          'data-cm-theme': instanceSettings.config.theme,
          'href': '/' + theme_css,
          'type': 'text/css',
          'rel': 'stylesheet'
        });

        $('head').append($css);
      });
    }
  };

}(jQuery, drupalSettings));
