<?php

/**
 * @file
 * Contains \Drupal\codemirror_field\CodemirrorField.
 */

namespace Drupal\codemirror_field;

class CodemirrorField {

  /**
   * Helper function to get the library path root path.
   */
  public static function libPath($subpath = '') {
    return drupal_get_path('module', 'codemirror_field') . '/vendor/codemirror/CodeMirror' . $subpath;
  }

  /**
   * Helper function to build a list of available mode options.
   */
  public static function getModeOptions() {
    $mode_names = array_keys(self::getMode());
    return array_combine($mode_names, $mode_names);
  }

  /**
   * Helper function to build a list of available mode options.
   */
  public static function getThemeCss($theme) {
    return self::libPath('/theme/') . $theme . '.css';
  }

  /**
   * Helper function to get the available codemirror themes.
   *
   * @return array
   *   Available codemirror themes.
   */
  public static function getThemeOptions() {
    $themes_path = self::libPath() . '/theme';
    $themes = file_scan_directory($themes_path, '/\.css/', array('key' => 'name'));

    foreach ($themes as $name => $theme) {
      $themes[$name] = $name;
    }

    $themes = array('default' => 'default') + $themes;

    ksort($themes);

    return $themes;
  }

  /**
   * Returns a single codemirror mode or all codemirror modes.
   *
   * @param string $mode
   *   The mode identifier for which the results are returned.
   *
   * @return array
   *   If a mode is given the function returns the settings for that, otherwise
   *   it returns all modes.
   */
  public static function getMode($mode = NULL) {
    $modes = array(
      'text/html' => array(
        'components' => array('xml', 'htmlmixed'),
        'addons' => array(
          'hint' => array(
            array('type' => 'xml'),
            array('type' => 'html'),
          ),
          'edit' => array(
            'matchbrackets' => array(),
            'matchtags' => array(),
          ),
          'fold' => array('xml-fold'),
        ),
        'extraKeys' => array(
          "Ctrl-Space" => "autocomplete",
        ),
      ),

      'css' => array(
        'components' => array('css'),
        'addons' => array(
          'hint' => array(
            array('type' => 'css'),
          ),
          'lint' => array(
            array('type' => 'css'),
          ),
          'edit' => array(
            'matchbrackets' => array(),
          ),
        ),
        'extraKeys' => array(
          "Ctrl-Space" => "autocomplete",
        ),
      ),

      'text/x-less' => array(
        'components' => array('css'),
        'addons' => array(
          'hint' => array(
            array('type' => 'css'),
          ),
          'lint' => array(
            array('type' => 'css'),
          ),
          'edit' => array(
            'matchbrackets' => array(),
          ),
        ),
        'extraKeys' => array(
          "Ctrl-Space" => "autocomplete",
        ),
      ),

      'javascript' => array(
        'components' => array('javascript'),
        'addons' => array(
          'hint' => array(
            array('type' => 'javascript'),
          ),
          'lint' => array(
            array('type' => 'javascript'),
          ),
          'edit' => array(
            'matchbrackets' => array(),
          ),
        ),
        'extraKeys' => array(
          "Ctrl-Space" => "autocomplete",
        ),
      ),
    );

    return isset($mode) ? (isset($modes[$mode]) ? $modes[$mode] : FALSE) : $modes;
  }


}
